@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPKPASS_FIELD_H
-#define KPKPASS_FIELD_H
+#pragma once
 
 #include "kpkpass_export.h"
 
@@ -21,6 +20,7 @@ namespace KPkPass
 class Pass;
 class PassPrivate;
 class FieldPrivate;
+class FieldTest;
 
 /** Field element in a KPkPass::Pass.
  * @see https://developer.apple.com/library/content/documentation/UserExperience/Reference/PassKit_Bundle/Chapters/FieldDictionary.html
@@ -65,6 +65,7 @@ public:
 
 private:
     friend class PassPrivate;
+    friend class FieldTest;
     explicit Field(const QJsonObject &obj, const Pass *pass);
 
     std::shared_ptr<FieldPrivate> d;
@@ -73,5 +74,3 @@ private:
 }
 
 Q_DECLARE_METATYPE(KPkPass::Field)
-
-#endif // KPKPASS_FIELD_H
